---
name: 🐛 Bug Report
about: File a bug report to help us improve
labels: bug
assignees: ""
---

**Bug Summary**

Please describe what you were trying to get done.

**What happened?**

Tell us what happened, what went wrong.

**What did you expect to happen?**

Describe what you expected to happen.

**Reproduction Steps**

Please provide a minimal, self-contained copy-pastable example that demonstrates the issue.

```python

```

**Relevant Log Output**

Please copy and paste any relevant output.

```console
```

**Anything else we need to know?**

Please describe any other information you want to share.

**Dev Environment Information**

Please provide some basic information about your dev environment (Python version, Orthant CLI Version, OS, etc.).

```console
<paste here>
```
